@@ -1,6 +1,6 @@
 var searchData=
 [
   ['3_200_208_0',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
-  ['3_200_20_3a_1',['Pre-requisites (OpenSSL &lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
+  ['3_200_20_3a_1',['Pre-requisites (OpenSSL &amp;lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
   ['3_3a_20opening_20a_20remote_20shell_2',['Chapter 3: Opening a remote shell',['../libssh_tutor_shell.html',1,'libssh_tutorial']]]
 ];
